@@ -7,12 +7,13 @@ use Net::DNS;
 
 use constant OS_SPEC => defined eval "require Net::DNS::Resolver::$^O";	## no critic
 use constant OS_CONF => join '::', 'Net::DNS::Resolver', OS_SPEC ? $^O : 'UNIX';
-use base qw(Net::DNS::Resolver::Base DynaLoader), OS_CONF;
+use base qw(Net::DNS::Resolver::Base DynaLoader);
+use base OS_CONF;
 
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.30_02';
+	$VERSION = '1.31_01';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
@@ -141,15 +142,15 @@ The following keywords are recognised in resolver configuration files:
 
 =over
 
-=item B<nameserver> address
+=item B<nameserver>
 
 IP address of a name server that the resolver should query.
 
-=item B<domain> localdomain
+=item B<domain>
 
 The domain suffix to be appended to a short non-absolute name.
 
-=item B<search> domain ...
+=item B<search>
 
 A space-separated list of domains in the desired search path.
 
@@ -551,7 +552,7 @@ END
 			push @image, sprintf( $format, $name, $value );
 		}
 	}
-	return join '', @image;
+	return join '', @image, "\n";
 }
 
 
@@ -649,7 +650,7 @@ sub _finalise_config {
 
 	my %option = map {$_} @$cfgopt, @$updopt;		# merge option updates
 	delete @option{@IPconf};				# expunge IP preference
-	foreach ( @IPpref ) {					# insert IP preference
+	foreach (@IPpref) {					# insert IP preference
 		my ( $key, $value ) = @{$IP_conf{$_}};
 		$option{$key} = $value;
 		last;
